@@ -20,7 +20,7 @@ from .defaults import (POSITIONAL,
 from .param import PARAM_MAPPINGS
 from .help import HelpAssembler, ProgHighlighter
 from .completer import Completer
-from .exceptions import PyParamNameError
+from .exceptions import PyParamNameError, PyParamTypeError, PyParamValueError
 
 class Params(Completer): # pylint: disable=too-many-instance-attributes
     """Params, served as root params or subcommands
@@ -85,7 +85,7 @@ class Params(Completer): # pylint: disable=too-many-instance-attributes
                                 else always_list(desc,
                                                  strip=False,
                                                  split=False))
-        self._prog: str = sys.argv[0] if prog is None else prog
+        self._prog: str = Path(sys.argv[0]).name if prog is None else prog
         self.help_keys: List[str] = (PARAMS_DEFAULT.help_keys
                                      if help_keys is None
                                      else always_list(help_keys))
@@ -443,16 +443,20 @@ class Params(Completer): # pylint: disable=too-many-instance-attributes
             the namespace with values of all parameter
                 name-value pairs
         """
+        # pylint: disable=too-many-branches
         ns_no_callback: Namespace = Namespace()
         for param_name, param in self.params.items():
             if param.is_help or param_name in ns_no_callback:
                 continue
             try:
                 value: Any = param.value
-            except (TypeError, ValueError) as pve:
+            except (PyParamTypeError, PyParamValueError) as pve:
                 if not ignore_errors:
                     logger.error("%r: %s", param.namestr(), pve)
                     self.print_help()
+            except Exception:
+                if not ignore_errors:
+                    raise
             else:
                 for name in param.names:
                     ns_no_callback[name] = value
@@ -465,10 +469,13 @@ class Params(Completer): # pylint: disable=too-many-instance-attributes
                 continue
             try:
                 value: Any = param.apply_callback(ns_no_callback)
-            except (TypeError, ValueError) as pte:
+            except (PyParamTypeError, PyParamValueError) as pte:
                 if not ignore_errors:
                     logger.error("%r: %s", param.namestr(), pte)
                     self.print_help()
+            except Exception:
+                if not ignore_errors:
+                    raise
             else:
                 for name in param.names:
                     setattr(namespace, name, value)
